@@ -21,16 +21,27 @@ class SecurityService:
         self.jwt = PyJWT()
         self.expires_after = 30
         self.not_before = 30
-        self.load_private_key()
-        self.load_shared_key(self.private_key)
+        self.private_key = None
+        self.shared_key = None
+        self.now = None
+        self.expires_at = None
+        self.token = None
+        self.private_key = self.load_pem(
+            self._config.private_key_mem if self._config.private_key_mem else self.load_private_key()
+        )
+        self.shared_key = bytes(self._config.shared_key, 'utf-8') if self._config.shared_key \
+            else self.load_shared_key(self.private_key)
         self.generate_token()
 
     def load_private_key(self, filename=None):
         filename = filename or self._config.private_key_file
         with open(filename, 'rb') as f:
             private_key_pem = f.read()
-        self.private_key = load_pem_private_key(
-            private_key_pem, password=None, backend=default_backend())
+        return private_key_pem
+
+    @staticmethod
+    def load_pem(private_key_pem):
+        return load_pem_private_key(private_key_pem, password=None, backend=default_backend())
 
     def load_shared_key(self, private_key,
                         filename=None):
@@ -38,7 +49,7 @@ class SecurityService:
         encrypted_key = None
         with open(filename, 'rb') as f:
             encrypted_key = b64decode(f.read())
-        self.shared_key = private_key.decrypt(encrypted_key, padding.PKCS1v15())
+        return private_key.decrypt(encrypted_key, padding.PKCS1v15())
 
     def generate_token(self):
         self.now = int(time.mktime(datetime.now().timetuple()))
@@ -60,7 +71,8 @@ class SecurityService:
             self.generate_token()
         return self.token
 
-    def httpdate(self):
+    @staticmethod
+    def httpdate():
         """Return a string representation of a date according to RFC 1123
         (HTTP/1.1).
 
@@ -75,7 +87,8 @@ class SecurityService:
         return '{}, {:02d} {} {:04d} {:02d}:{:02d}:{:02d} GMT'.format(
             weekday, now.day, month, now.year, now.hour, now.minute, now.second)
 
-    def calculate_digest(self, msg):
+    @staticmethod
+    def calculate_digest(msg):
         sha = hashlib.sha256()
         sha.update(msg)
         return b64encode(sha.digest())
@@ -92,10 +105,10 @@ class SecurityService:
         logging.debug(self.shared_key)
         signature = hmac.new(self.shared_key, msg=message, digestmod=hashlib.sha256).digest()
         authorization = f'hmac username="{self._config.consumer_name}", algorithm="hmac-sha256", ' \
-            f'headers="digest x-date request-line", signature="{b64encode(signature).decode()}" '
-
-        return {'digest': digest, 'x-date': x_date, 'authorization': str(authorization), 'user-agent': 'coin-sdk-python-1.0.5'}
+                        f'headers="digest x-date request-line", signature="{b64encode(signature).decode()}" '
 
+        return {'digest': digest, 'x-date': x_date, 'authorization': str(authorization),
+                'user-agent': 'coin-sdk-python-1.1.1'}
 
     def generate_jwt(self):
         return {'jwt': f'{self.get_token()}'}
