@@ -45,7 +45,7 @@ class Receiver(ABC):
             return self._number_of_retries > 0
 
         def backoff(self):
-            logger.error(f'Trying to reconnect in {self._backoff_period} seconds. Retries left: {self.get()}')
+            logger.warning(f'Trying to reconnect in {self._backoff_period} seconds. Retries left: {self.get()}')
             time.sleep(self._backoff_period)
             self._number_of_retries -= 1
             self._backoff_period = min(self._backoff_period*2, 60)
@@ -96,13 +96,15 @@ class Receiver(ABC):
                 self._connect(offset, confirmation_status, message_types, retries_left)
                 return
             except (ConnectionError, ChunkedEncodingError, ReadTimeout) as e:
-                # ChunckedEncodingError occurs when backend stops while waiting for new events
-                logger.error(type(e).__name__)
-                logger.error(e)
+                # ChunkedEncodingError occurs when backend stops while waiting for new events
+                if not(isinstance(e, ChunkedEncodingError)):
+                    logger.warning(type(e).__name__)
+                    logger.warning(e)
                 if self._offset_persister:
                     offset = self._offset_persister.get_persisted_offset()
                     offset = self._recover_offset(offset)
                 retries_left.backoff()
+        logger.error("No retries left. Stopped consuming messages.")
 
     def _setup(
             self,
